@@ -1,4 +1,5 @@
-from dagster.core.storage.io_manager import IOManager, io_manager as dagster_io_manager
+from dagster.core.storage.io_manager import IOManager
+from dagster.core.storage.io_manager import io_manager as dagster_io_manager
 from qdk.materialization import Materializer
 
 
@@ -10,6 +11,8 @@ class QDKIOManager(IOManager):
         keys = tuple(context.get_output_identifier())
         self.values[keys] = obj
 
+        print("After storing:", self.values)
+
         # Create a materializer for the object
         asset_materialization = Materializer(
             asset_key=[
@@ -28,10 +31,11 @@ class QDKIOManager(IOManager):
 
     def load_input(self, context):
         keys = tuple(context.upstream_output.get_output_identifier())
+        print("After loading:", self.values, keys)
         obj = self.values[keys]
         return obj
 
 
 @dagster_io_manager
-def io_manager(_):
+def qdk_io_manager(_):
     return QDKIOManager()
