@@ -9,7 +9,7 @@ from dagster import (
 from dagster.core.execution.results import SolidExecutionResult
 from dask.dataframe import DataFrame as DaskDataFrame
 from pandas import DataFrame
-from qdk import DataFrameLoader, YakeComponent, io_manager
+from qdk import DataFrameLoader, YakeComponent, qdk_io_manager
 
 from ..utils.dataframe import CSVStoreDataFrame
 
@@ -20,7 +20,7 @@ keyword_solid = YakeComponent.to_solid(
 )
 
 
-@pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": io_manager})])
+@pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": qdk_io_manager})])
 def nlp_pipeline():
     df = loader_solid()
     keyword = keyword_solid(df)
